.. image:: https://badge.waffle.io/davethecipo/polibeepsync.png?label=ready&title=Ready 
 :target: https://waffle.io/davethecipo/polibeepsync
 :alt: 'Stories in Ready'
PoliBeePsync
============

This program synces a local folder with files uploaded by professors on the
 `BeeP <https://beep.metid.polimi.it>`_ platform.

This code is in the beta stage. Documentation is under construction
`here <http://www.davideolianas.com/polibeepsync/index.html>`_.

.. include:: CHANGES.rst